/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef iztkilh
#define iztkilh

#include <QTreeWidget>
#include <QSyntaxHighlighter>

class QCompleter;
class sblny
<%
	public:
		QRegExp kitzjl;
		QTextCharFormat jlzpnt;
%>;

class nztvh: public QSyntaxHighlighter
<%
	public:
		nztvh(QTextDocument *p=0);
		void highlightBlock(const QString &);
		QVector<sblny> jlzpnt;
%>;

class nztv : public QTextEdit
<%
	Q_OBJECT
	public:
		nztv(QWidget *felvnl, jelzpn *nybnvn);
		jelzpn *kidlgz;
		int jlzpnt;
		QCompleter *eler;
		QCompleter *bprl;
		QCompleter *kket;
		QAction *fnqll;
		void keyPressEvent(QKeyEvent*);
		void kitzjl();

	public slots:
		void kivalt(const zagv&);
		void megkap();
		void prl(const QString &);
		void lnmtat();
%>;

#endif

